# R version 4.1.2 (2021-11-01) 
# R skript to reproduce the results and graphs for manuscript: Mueller et al, 
# Soundscapes and artificial intelligence provide powerful tools to track biodiversity recovery in tropical forests
# 
#	data are soundscapes collected on 43 plots in Ecuador along a recovery gradient in the Choco region
# 	additionally light trap samples were collected on same plots and analysed by metabarcoding
#	Bird data were analysed by two experts (Rudy Gelis and Juan Freile) for two separate sets of audio-files

rm(list=ls(all=TRUE))

library(vegan)
library(ncf)
library(lme4)
library(multcomp)
library(effects)

###############################################################################################################
#we start with a community analyses of all vocalizing vertebrates (birds and mammals) identified by Rudy Gelis and Alejandro Artega 
################
all_G<-read.csv2("community_data_frogs_birds_mammals_Gelis_OG.csv", row.names=1,header=T)
names(all_G)
dim(all_G)

#reading the environmental data for the 43 plots
environ<-read.csv2("Environ_SoundIndices43.csv", header=T)
environ$Category_ord<-ordered(environ$Category, c("Pasture","Cacao","PRegI","CRegI","PRegII","CRegII","Oldgr"))

dim(environ)
names(environ)

#matching community and environmental data
all2_G<-all_G[as.vector(environ$Soundbox_Name),]
dim(all2_G)

#Defining colours for plotting of the ordination under consideration of colorblind people
clrs2 <- c("#F0E442","#E69F00","#D55E00", "#009E73","#56B4E9","#0072B2", "#CC79A7")
pie(rep(1, 7), col = clrs2)
# 1: Cacao  2: CRegI  3: CRegII, 4: old growth 5: Pasture  6: PRegI  7: PRegII

set.seed(29)
#NMDS ordination of the total community Gelis
metaMDS.all_G<-metaMDS(all2_G, distance = "bray", k=3,trymax = 100)
plot(metaMDS.all_G,display = "sites",type="p",cex=0.8, las=1) # 
ordihull(metaMDS.all_G, environ$Category, display = "sites", draw = c("polygon"), col=clrs2)
ordispider(metaMDS.all_G, environ$Category,  
	 spiders = c("median"),  
         label = TRUE,cex=0.7,bg=clrs2,col = clrs2)
text(metaMDS.all_G, display = "sites", labels=rownames(all2_G),cex=0.6, choices = c(1, 2)) # just for checking individual plots

#The graph shows that the first axis again well represents the recovery gradient
#This species composition is therefore used as second validation Axis in the next analyses
environ$Vertebrates_Axis1_Gelis<-metaMDS.all_G$points[,1]*-1 # Multiplication by -1 to turn the gradient from agriulture to old-growth
environ$Vertebrates_Axis2_Gelis<-metaMDS.all_G$points[,2] 

##########################################################################################
# now only for the 49 birds represented in CNN models
birds_CNN_org<-read.csv2("community_data_birds_Gelis_CNN.csv", row.names=1,header=T)
names(birds_CNN_org)
dim(all_G)

CNN_list<-read.csv2("Listof49sharedSpecies.csv", header=T)
names(CNN_list)
birds_CNN_org2<-birds_CNN_org[as.vector(environ$Soundbox_Name),as.vector(CNN_list$Species_Experts)]
dim(birds_CNN_org2)

metaMDS.CNNspecies_G<-metaMDS(birds_CNN_org2, distance = "bray", k=3,trymax = 100)
plot(metaMDS.CNNspecies_G,display = "sites",type="p",cex=0.8) # 
ordihull(metaMDS.CNNspecies_G, environ$Category, display = "sites", draw = c("polygon"), col=clrs2)
ordispider(metaMDS.CNNspecies_G, environ$Category,  
	 spiders = c("median"),  
         label = TRUE,cex=0.7,bg=clrs2,col = clrs2)
text(metaMDS.CNNspecies_G, display = "sites", labels=rownames(all2_G),cex=0.6, choices = c(1, 2))
environ$Vertebrates_Axis1_Gelis_49<-metaMDS.CNNspecies_G$points[,1]*-1 # Multiplication by -1 to turn the gradient from agriulture to old-growth
environ$Vertebrates_Axis2_Gelis_49<-metaMDS.CNNspecies_G$points[,2] 

#Calculation of Recordings
environ$Recordings<-rowSums(all2_G)# Numbers of recordings
#Calculation of Richness 
environ$Oldg_Richness_G<-specnumber(all2_G[,c(108:183,209:227)])# Numbers of species recorded from old growth plots
environ$All_Richness_G<-specnumber(all2_G) # Total species richness

##########################################################################################################
# Now we check robustness of the ordination results by rerunning the ordination for second expert (Freile) bird identification
all_F<-read.csv2("community_data_frogs_birds_mammals_Freile_OG.csv", row.names=1,header=T)
names(all_F)
dim(all_F)

#matching community and environmental data
all2_F<-all_F[as.vector(environ$Soundbox_Name),]
dim(all2_F)
set.seed(29)
#ordination of the total community
metaMDS.all_F<-metaMDS(all2_F, distance = "bray", k=3,trymax = 100)
plot(metaMDS.all_F,display = "sites",type="p",cex=0.8) # 
ordihull(metaMDS.all_F, environ$Category, display = "sites", draw = c("polygon"), col=clrs2 )
ordispider(metaMDS.all_F, environ$Category,  
	 spiders = c("median"),  
         label = TRUE,cex=0.7,bg=clrs2,col = clrs2)

# Comparision of both ordination axis
environ$Vertebrates_Axis1_Freile<-metaMDS.all_F$points[,1] *(-1)
environ$Vertebrates_Axis2_Freile<-metaMDS.all_F$points[,2] 

cor.test(environ$Vertebrates_Axis1_Gelis,  environ$Vertebrates_Axis1_Freile)

# now we can plot Figure S4: Comparision of first vertebrate axis with two different bird experts 
pdf(file="Figure_S4.pdf", height=6, width=6)
par(oma=c(2,2,1,1))
plot(Vertebrates_Axis1_Gelis ~ environ$Vertebrates_Axis1_Freile,pch=21,cex=1.5,las=1, bg="gray",
xlab="Community vertebrate axis 1 (Expert 2)",ylab="Community vertebrate axis 1 (Expert 1)",
data=environ)
text(-0.7,0.3,"r=0.94", cex=1.3)
abline(a=0,b=1)
dev.off()

#for further sound indices calculations we had to remove one plot because of technical problems in the audio files
#this 42 data set is created now
environ_subset <- subset(environ, Soundbox_Name!="SR_12") # 
names(environ_subset)

############################################################################
# CNN Bird identification
# Finally 73 species were accpeted as occuring the region and identified on the plots by CNN
#################################################################################

birds_AI80<-read.csv2("AI Community_43_0.80_73.csv", row.names=1,header=T)
names(birds_AI80)
birds_AI80<-birds_AI80[as.vector(environ$Soundbox_Name),] # Sorting in the same order as Environ
row.names(birds_AI80)==environ$Soundbox_Name
dim(birds_AI80)

set.seed(29)
#MetaNMDS
metaMDS.birds80<-metaMDS(birds_AI80, distance = "bray", k=3,trymax = 100)
plot(metaMDS.birds80,display = "sites", col=0,cex=0.01) # 
ordihull(metaMDS.birds80, environ$Category, display = "sites", draw = c("polygon"), col=clrs2)
ordispider(metaMDS.birds80, environ$Category,  
	 spiders = c("median"), col=clrs2,  
         label = TRUE)
text(metaMDS.birds80, display = "sites", labels=rownames(birds_AI80),cex=0.8,col="red", choices = c(1, 2))

#extracting the first and second axis from AI
environ$AIcom_80_axis1<-(metaMDS.birds80$points[,1]*-1)
environ$AIcom_80_axis2<-(metaMDS.birds80$points[,2]*-1)

####################################################################################

#now we extract from AI community only those species occuring also in data from Gelis
names(CNN_list)
birdsAI_Gelis49<-birds_AI80[as.vector(environ$Soundbox_Name), as.vector(CNN_list$CNN_Species)]
dim(birdsAI_Gelis49)

metaMDS.birdsCNN49_Gelis<-metaMDS(birdsAI_Gelis49, distance = "bray", k=3,trymax = 100)
plot(metaMDS.birdsCNN49_Gelis,display = "sites", col="white",cex=0.01) # 
ordihull(metaMDS.birdsCNN49_Gelis, environ$Category, display = "sites", draw = c("polygon"), col=clrs2)
ordispider(metaMDS.birdsCNN49_Gelis, environ$Category,  
	 spiders = c("median"), col=clrs2,  
         label = TRUE)
text(metaMDS.birdsCNN49_Gelis, display = "sites", labels=rownames(birds_AI80),cex=0.8,col="red", choices = c(1, 2))
environ$AIcom_49_Gelis_axis1<-(metaMDS.birdsCNN49_Gelis$points[,1]*-1)
environ$AIcom_49_Gelis_axis2<-(metaMDS.birdsCNN49_Gelis$points[,2]*-1)

# Multiple regression models################################################################

#One plot is damaged for sound indices SR_12
environ_subset <- subset(environ, Soundbox_Name!="SR_12")
names(environ_subset)
dim(environ_subset)

#Model of Vocalizing vertebrate total Richness# Table 1
modRich_All_G<-lm(log(All_Richness_G) ~  TemporalEntropy + AcousticComplexity + EntropyOfVarianceSpectrum 
											+ SoundscapeSaturation + EventsPerSecond, data=environ_subset)
summary(modRich_All_G)


#Test for spatial independence of the residuals of the model
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modRich_All_G$residuals, resamp = 999))
## The confidence value includes the zero line

# A set of models using five soundscape indices (Table 1)
#Model of Vocalizing old growth inhabiting vertebrate Richness# Table 1
modRich_OG_G<-lm(log(Oldg_Richness_G) ~  TemporalEntropy + AcousticComplexity + EntropyOfVarianceSpectrum 
									+ SoundscapeSaturation + EventsPerSecond, data=environ_subset)
summary(modRich_OG_G)
#Test for spatial independence of residuals
# univariate spline correlogram
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modRich_OG_G$residuals, resamp = 999))

#Model of Vocalizing vertebrate community axis 1# Table 1
modCom_G<-mod.axis1_Gelis<-lm(Vertebrates_Axis1_Gelis ~  TemporalEntropy +AcousticComplexity + EntropyOfVarianceSpectrum 
											+ SoundscapeSaturation + EventsPerSecond, data=environ_subset)
summary(modCom_G)
#Test for spatial independence of residuals
# univariate spline correlogram
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modCom_G$residuals, resamp = 999))

modLightT_Axis1<-lm(LightT_Axis1 ~  TemporalEntropy + AcousticComplexity + EntropyOfVarianceSpectrum 
											+ SoundscapeSaturation + EventsPerSecond, data=environ_subset)
summary(modLightT_Axis1)
# univariate spline correlogram
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modLightT_Axis1$residuals, resamp = 999))


# Now we model the target variables using the first axis of CNN bird community composition
modCom_G_AI<-mod.axis1_Gelis_AI<-lm(Vertebrates_Axis1_Gelis ~  AIcom_80_axis1, data=environ)
summary(modCom_G_AI)
#Test for spatial independence of residuals
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modCom_G_AI$residuals, resamp = 999))

modLightT_CNN<-lm(LightT_Axis1 ~  AIcom_80_axis1, data=environ)
summary(modLightT_CNN)
# univariate spline correlogram
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modLightT_CNN$residuals, resamp = 999))


#Figure_S5 Spatial independence
pdf(file="Figure_S5.pdf", height=9, width=6)
layout(matrix(c(1,2,3,4,5,6), byrow=TRUE, ncol=2))
par(oma=c(2,2,1,1), las=1, cex.main=1.2)

plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modRich_All_G$residuals, resamp = 999),
					main="Richness versus\n Sound Indices")
box()
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modRich_OG_G$residuals,resamp = 999), 
			main="Old-growth Richness versus\n Sound Indices")
box()
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modCom_G$residuals, resamp = 999),
			main="Vertebrate community axis 1\n versus Sound Indices")
box()
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modLightT_Axis1$residuals, resamp = 999),
		main="Insect community versus\n Sound Indices")
box()
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modCom_G_AI$residuals, resamp = 999),
		main="Vertebrate community axis1\n versus CNN-community")
box()
plot(spline.correlog(x = environ$X_Plot, y = environ$Y_Plot, z = modLightT_CNN$residuals,
				resamp = 999),main="Insect community\n versus CNN-community")
box()
dev.off()


# We now predict the axis scores of Vocalizing vertebrate communities by Sound Indices in prepartion for Figure 1
mod.axis1_Gelis<-lm(Vertebrates_Axis1_Gelis ~  TemporalEntropy +AcousticComplexity + EntropyOfVarianceSpectrum 
											+ SoundscapeSaturation + EventsPerSecond, data=environ_subset)
environ_subset$SoundIndexModel_PredictionAxis1_Gelis<-predict(mod.axis1_Gelis)
names(environ_subset)

boxplot(SoundIndexModel_PredictionAxis1_Gelis ~ Category_ord, environ_subset)
boxplot(Vertebrates_Axis1_Gelis ~ Category_ord, environ_subset)


##########Testing for difference in Figure 1b by methods ################################################
test_data<-rbind(data.frame(Plot=environ_subset$Soundbox_Name, 
                     Habitat=environ_subset$Category, 
                     Score=as.numeric(environ_subset$Vertebrates_Axis1_Gelis), 
                     Method=rep("expert",length(environ_subset[,1]))),
               data.frame(Plot=environ_subset$Soundbox_Name, 
                     Habitat=environ_subset$Category, 
                     Score=as.numeric(environ_subset$SoundIndexModel_PredictionAxis1_Gelis), 
                     Method=rep("Acoustic",length(environ_subset[,1])))
)
summary(test_data)

model_pair<-lmer(Score ~ Habitat + Habitat:Method + (1 | Plot), test_data)
cftest(model_pair)
# The model shows that the difference in scores is significant in old-growths and pastures
# now we can plot Figure 1
########Figure_1############
pdf(file="Figure_1.pdf", height=6, width=12)
layout(matrix(c(1,2), byrow=TRUE, ncol=2))
par(oma=c(2,2,1,1))

plot(metaMDS.all_G,xlab="Community vertebrates Axis 1", ylab="Axis 2",display = "sites",type="p",cex=0.8,cex.lab=1.3, cex.axis=1.0,axes=FALSE,cex.main=1.1) # 
axis(1)
axis(2, las=2)
box()
ordihull(metaMDS.all_G, environ$Category, display = "sites", draw = c("polygon"),border=clrs2, col=clrs2 )
ordispider(metaMDS.all_G, environ$Category,  
	 spiders = c("median"),  
         label = TRUE,cex=0.7,bg=clrs2,col = clrs2)
text(-0.68,0.83,"a)",cex=1.2)

boxplot(Vertebrates_Axis1_Gelis ~ Category_ord, data = environ_subset,
        boxwex = 0.3, at = 1:7 - 0.17,boxfill = "light gray",axes=FALSE,cex.lab=1.3, 
		whisklty=1,staplelty=0,
        #subset = supp == "VC", 
		col = "dark gray",
	        xlab = "Recovery gradient",
        ylab = "Community vertebrates (-1 x axis1)",
        ylim = c(-1.3, 1.0),
	  yaxs = "i")
axis(1, at=1:7, labels=c("Pasture","Cacao","PRegI","CRegI", "PRegII","CRegII","Oldgr"),cex.axis=0.8)

                  
axis(2,las=1)
box()
text(0.3,0.87,"b)", cex=1.2)

boxplot(SoundIndexModel_PredictionAxis1_Gelis ~ Category_ord, data = environ_subset, add = TRUE,
        boxwex = 0.3, at = 1:7 + 0.17,axes=FALSE,whisklty=1,staplelty=0,
        #subset = supp == "OJ", 
		col = "white", names = c("",
                  "","",""))
legend(0.7, 0.9, c("Expert community", "Sound prediction"),
       fill = c("light gray", "white"))
text(1,-0.25,expression(paste("***")))
text(7,0.9,expression(paste("***")))
dev.off()

##################################################################
#Figure S2
#creating colour codes in line with Figure 1a
clrs3 <- c("#F0E442","#56B4E9","#E69F00","#0072B2","#CC79A7","#D55E00","#009E73")
pie(rep(1, 7), col = clrs3)


pdf(file="Figure_S3.pdf", height=5, width=4)
layout(matrix(c(1,2), byrow=TRUE, ncol=1))
par(mar = c(5, 5, 1, 1) + 0.1)
boxplot(All_Richness_G ~ Category_ord, las=1,col = clrs3,xaxt = "n",
	whisklty=1,staplelty=0, xlab = "", ylab = "Species richness\nall species",data = environ_subset)
text(0.5,54,"a)", cex=1.2)
text(x = 1:7, # Move labels to just below bottom of chart.
     y = par("usr")[3] - 2.8,# Use names from the data list
     labels = c("","","","","","",""),# Change the clipping region
     xpd = NA, # Rotate the labels by 35 degrees
     srt = 25, # Adjust the labels to almost 100% right-justified.
     adj = 0.9, # Increase label size.
     cex = 0.9)
par(mar = c(5, 5, 1, 1) + 0.1)
boxplot(Oldg_Richness_G ~ Category_ord, las=1, col = clrs3,xaxt = "n",
					whisklty=1,staplelty=0,xlab = "Recovery gradient", ylab = "Species richness\nold-growth species",data = environ_subset)
text(0.5,38,"b)", cex=1.2)
text(x = 1:7,
     y = par("usr")[3] - 2.8,
     labels = c("Pasture","Cacao","P Reg I","C Reg I","C Reg II","P Reg II","Old-growth"),
     xpd = NA,
     srt = 25,
     adj = 0.9,
    cex = 0.8)
dev.off()

###########################################
#Figure 3 Partial Effect plot for Community Axis 1 Gelis

eff.axis1_Gelis <- allEffects(mod.axis1_Gelis, residuals=TRUE)
plot(eff.axis1_Gelis[3])

#Figure_3_1
tiff(filename = "Figure_3_1.tif", width = 110, height = 110,
     units = "mm", res = 700, 
     compression = "lzw")
plot(eff.axis1_Gelis[2],main="",ylab="Community vertebrates Axis 1",xlab="Acoustic complexity",
lwd=2, partial.residuals=list(smooth=FALSE), residuals.color ="darkgray", 
		residuals.pch=1, residuals.cex=0.8,
		lines=list(col="black", alpha=.5),
		confint=list(col="light gray", alpha=.5))
dev.off()

#Figure_3_2
tiff(filename = "Figure_3_2.tif", width = 110, height = 110,
     units = "mm", res = 700, 
     compression = "lzw")
plot(eff.axis1_Gelis[3],main="",ylab="Community vertebrates Axis 1",xlab="Entropy of Frequency",
lwd=2, partial.residuals=list(smooth=FALSE), residuals.color ="darkgray", 
		residuals.pch=1, residuals.cex=0.8,
		lines=list(col="black", alpha=.5),
		confint=list(col="light gray", alpha=.5))
dev.off()

#Figure_3_3
tiff(filename = "Figure_3_3.tif", width = 110, height = 110,
     units = "mm", res = 700, 
     compression = "lzw")
plot(eff.axis1_Gelis[4],main="",ylab="Community vertebrates Axis 1",xlab="Soundscape saturation",
lwd=2, partial.residuals=list(smooth=FALSE), residuals.color ="darkgray", 
		residuals.pch=1, residuals.cex=0.8,
		lines=list(col="black", alpha=.5),
		confint=list(col="light gray", alpha=.5))
dev.off()

#Figure_3_4
tiff(filename = "Figure_3_4.tif", width = 110, height = 110,
     units = "mm", res = 700, 
     compression = "lzw")
plot(eff.axis1_Gelis[5],main="",ylab="Community vertebrates Axis 1",xlab="Events/second",
lwd=2, partial.residuals=list(smooth=FALSE), residuals.color ="darkgray", 
		residuals.pch=1, residuals.cex=0.8,
		lines=list(col="black", alpha=.5),
		confint=list(col="light gray", alpha=.5))
dev.off()

#####################################################################################################
#Preparation for Figure 2 with correlation plots and confidence bands
y_L<-environ$LightT_Axis1 
y_V<-environ$Vertebrates_Axis1_Gelis
x<-environ$AIcom_80_axis1

y_V51<-environ$Vertebrates_Axis1_Gelis_49  # Vertebraten Communitiy only with 49 bird species shared with CNN
x2<-environ$AIcom_49_Gelis_axis1  # CNN axis only with 49 species shared with Gelis

lm.L <- lm(y_L ~ x)
summary(lm.L)

lm.V <- lm(y_V ~ x)
summary(lm.V)

lm.AI <- lm(y_V51 ~ x2)
summary(lm.AI)

newx = seq(min(x),max(x),by = 0.01)
conf_interval_L <- predict(lm.L, newdata=data.frame(x=newx), interval="confidence",
                         level = 0.95)
conf_interval_V <- predict(lm.V, newdata=data.frame(x=newx), interval="confidence",
                         level = 0.95)
newx2 = seq(min(x2),max(x2),by = 0.001)
conf_interval_AI <- predict(lm.AI, newdata=data.frame(x2=newx2), interval="confidence",
                         level = 0.95)

pdf(file="Figure_2.pdf", height=8, width=8)
layout(matrix(c(1,2,3,4), byrow=TRUE, ncol=2))
par(mar=c(5,4,2.5,2),cex.lab=1.2)

plot(x, y_V, xlab="CNN-derived bird community axis 1", ylab="Community vocalizing vertebrates",las=1,  type = 'n')
polygon(c(rev(newx), newx), c(rev(conf_interval_V[ ,3]), conf_interval_V[ ,2]), col = 'light grey', border = NA)
lines(newx, conf_interval_V[,1], col="black", lty=1)
points(x, y_V, xlab="x", ylab="y", pch=21, col="dark gray")
text(-0.6, y=0.4, labels="R²=0.69",cex=1.3)  
text(-0.8, y=0.6, labels="a)",cex=1.3)
box()

plot(x, y_L, xlab="CNN-derived bird community axis 1", ylab="Community Insect composition",las=1,  type = 'n')
polygon(c(rev(newx), newx), c(rev(conf_interval_L[ ,3]), conf_interval_L[ ,2]), col = 'light grey', border = NA)
lines(newx, conf_interval_L[,1], col="black", lty=1)
points(x, y_L, xlab="x", ylab="y", pch=21, col="dark gray")
text(-0.6, y=0.3, labels="R²=0.39",cex=1.3)  
text(-0.8, y=0.44, labels="b)",cex=1.3)
box()

plot(x2, y_V51, xlab="CNN-derived bird community 49 spec.", ylab="Community vocalizing vertebrates 49 spec.",las=1,  type = 'n')
polygon(c(rev(newx2), newx2), c(rev(conf_interval_AI[ ,3]), conf_interval_AI[ ,2]), col = 'light grey', border = NA)
lines(newx2, conf_interval_AI[,1], col="black", lty=1)
points(x2, y_V51, xlab="x", ylab="y", pch=21, col="dark gray")
text(-0.7, y=0.4, labels="R²=0.85",cex=1.3)  
text(-0.9, y=0.7, labels="c)",cex=1.3)
box()

dev.off()




